{% extends "basket/base.html" %}
{% load i18n %}

{% block title %}{% trans 'Order completed!' %}{% endblock title %}

{% block content %}
    <p>
    {% blocktrans %}
    Congratulations, your order is received.
    Within an hour our manager will contact you to confirm the availability of goods ordered.
    {% endblocktrans %}
    </p>
{% endblock %}
