{% extends "basket/base.html" %}
{% load i18n %}

{% block title %}{% trans 'Checkout' %}{% endblock title %}

{% block content %}
    <form action="." id="basket_order_submit_form" method="post">
	<table>
		{{ form }}
        {% csrf_token %}
		<tr><td colspan="2">
			<input type="button" class="submit" value="{% trans 'Back' %}" onclick="document.location = '{% url basket %}';"/>
			<input type="submit" class="submit" value="{% trans 'Submit' %}" />
		</td></tr>
	</table>
    </form>
{% endblock %}
