<div class="add-to-basket">
	{% if already_in %}
		<div class="already-in-basket">
			{{ already_in_text }}
		</div>
	{% endif %}
	<div class="basket-button">
		<a href="#" onclick="return basket.add(this, {{ content_type.id }}, {{ object.id }});">
			{{ button_text }}
		</a>
	</div>
	<div class="basket-added" style="display: none;">{{ added_text }}</div>
</div>