{% extends "basket/base.html" %}
{% load i18n %}

{% block title %}{% trans 'Your basket is empty' %}{% endblock title %}

{% block content %}
<h1>{% trans 'Your basket is empty' %}</h1>

{% endblock %}